package com.inet.taskplanner.openweathermap;

/**
 * Defines the available units setting for getting weather data.
 */
public enum Units {

    /**
     * Default units with Kelvin and meters per second
     */
    DEFAULT( "K", "m/s" ),
    /**
     * Metric units with Celsius und kilometers per hour
     */
    METRIC( "°C", "km/h" ),
    /**
     * Imperial units with Fahrenheit and miles per hour
     */
    IMPERIAL( "°F", "mph" );

    private String temperatureUnit;
    private String speedUnit;

    /**
     * Creates the units.
     * @param temperatureUnit the unit for the temperature
     * @param speedUnit the unit for the wind speed
     */
    private Units( String temperatureUnit, String speedUnit ) {
        this.temperatureUnit = temperatureUnit;
        this.speedUnit = speedUnit;
    }

    /**
     * Returns the unit for the temperature
     * @return the unit for the temperature
     */
    public String getTemperatureUnit() {
        return temperatureUnit;
    }

    /**
     * Returns the unit for the wind speed
     * @return the unit for the wind speed
     */
    public String getSpeedUnit() {
        return speedUnit;
    }

}
